ArgumentError

Enum ArgumentError 

#[non_exhaustive]
pub enum ArgumentError { MissingCommand, UnknownCommand, UnknownOption { option: String, }, OptionNotAccepted { option: String, command: Command, }, MissingValue { option: String, }, RepeatedOption { option: String, }, InvalidValue { option: String, }, MissingRequiredOption { option: String, command: Command, }, ContradictoryOptions { first: String, second: String, }, InvalidConfigurationValue { option: String, }, }
A rejected invocation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingCommand

No command word was supplied.



UnknownCommand

The words did not name a command of the closed grammar.



UnknownOption

The option is not part of the grammar.

Fields

option: String

Rejected option, without its value.



OptionNotAccepted

The option is not accepted by this command.

Fields

option: String

Rejected option.

command: Command

Command that does not accept it.



MissingValue

The option requires a value that was not supplied.

Fields

option: String

Option missing its value.



RepeatedOption

A single-valued option was supplied more than once.

Fields

option: String

Repeated option.



InvalidValue

The value could not be parsed as the option’s type.

Fields

option: String

Option whose value was rejected.



MissingRequiredOption

A required option was not supplied.

Fields

option: String

Missing option.

command: Command

Command that requires it.



ContradictoryOptions

Two options that cannot be combined were both supplied.

Fields

first: String

First option.

second: String

Second option.



InvalidConfigurationValue

The value of a configuration option was rejected.

This variant reports ExitCategory::ConfigurationInvalid because the same value can be supplied by an environment variable or a file.

Fields

option: String

Option whose value was rejected.

Implementations

Source

impl ArgumentError

pub const fn category(&self) -> ExitCategory

Returns the exit category this rejection reports.

pub const fn code(&self) -> &'static str

Returns the stable machine code of this rejection.