#[non_exhaustive]pub enum CatalogError {
AnonymousDefinition,
DuplicateJob {
job_name: JobName,
},
}Expand description
A rejected catalog registration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AnonymousDefinition
The identity carries no job name, so it selects no job.
DuplicateJob
The job name is already registered with a different identity.