#[non_exhaustive]pub enum Outcome {
Success,
Rejected,
Conflict,
Unknown,
Error,
}Expand description
The outcome field of the versioned JSON envelope.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Success
The command applied or replayed its effect.
Rejected
A guard or a confirmation rule refused the action.
Conflict
An optimistic version lost its compare-and-swap.
Unknown
The durable outcome is undetermined and must be replayed.
Error
The command failed before reaching a durable decision.
Implementations