pub struct Configuration { /* private fields */ }Expand description
The effective configuration of one invocation.
Implementations
Sourceimpl Configuration
impl Configuration
Sourcepub const fn repository_url(&self) -> Option<&Resolved<Secret>>
pub const fn repository_url(&self) -> Option<&Resolved<Secret>>
Borrows the repository connection secret, when one was supplied.
Sourcepub const fn ca_certificate(&self) -> Option<&Resolved<Secret>>
pub const fn ca_certificate(&self) -> Option<&Resolved<Secret>>
Borrows the PEM certificate-authority bundle, when one was supplied.
Sourcepub const fn tls_mode(&self) -> TlsSetting
pub const fn tls_mode(&self) -> TlsSetting
Returns the selected transport security.
Sourcepub const fn connect_timeout(&self) -> Duration
pub const fn connect_timeout(&self) -> Duration
Returns the validated connection establishment timeout.
Sourcepub const fn statement_timeout(&self) -> Duration
pub const fn statement_timeout(&self) -> Duration
Returns the validated server-side statement timeout.
Sourcepub const fn output(&self) -> OutputForm
pub const fn output(&self) -> OutputForm
Returns the effective output form.
Sourcepub const fn client_timeout(&self) -> Duration
pub const fn client_timeout(&self) -> Duration
Returns the effective client deadline.
Sourcepub fn effective(&self) -> Vec<EffectiveValue>
pub fn effective(&self) -> Vec<EffectiveValue>
Returns every effective value with its source and redaction status.
The value column of a secret-bearing key is always the redaction marker, never the value.