pub struct SchemaState {
pub installed: Option<u32>,
pub supported: u32,
}Expand description
The durable schema state one repository reports.
Fields
installed: Option<u32>The schema version installed in the repository, when one is readable.
supported: u32The schema version this build supports.
Implementations
Sourceimpl SchemaState
impl SchemaState
Sourcepub const fn migration_required(&self) -> bool
pub const fn migration_required(&self) -> bool
Returns whether the installed schema requires migration.
Sourcepub const fn newer_than_supported(&self) -> bool
pub const fn newer_than_supported(&self) -> bool
Returns whether the installed schema is newer than this build supports.