#[non_exhaustive]pub enum ArgumentError {
MissingCommand,
UnknownCommand,
UnknownOption {
option: String,
},
OptionNotAccepted {
option: String,
command: Command,
},
MissingValue {
option: String,
},
RepeatedOption {
option: String,
},
InvalidValue {
option: String,
},
MissingRequiredOption {
option: String,
command: Command,
},
ContradictoryOptions {
first: String,
second: String,
},
InvalidConfigurationValue {
option: String,
},
}Expand description
A rejected invocation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingCommand
No command word was supplied.
UnknownCommand
The words did not name a command of the closed grammar.
UnknownOption
The option is not part of the grammar.
OptionNotAccepted
The option is not accepted by this command.
MissingValue
The option requires a value that was not supplied.
RepeatedOption
A single-valued option was supplied more than once.
InvalidValue
The value could not be parsed as the option’s type.
MissingRequiredOption
A required option was not supplied.
ContradictoryOptions
Two options that cannot be combined were both supplied.
InvalidConfigurationValue
The value of a configuration option was rejected.
This variant reports ExitCategory::ConfigurationInvalid because the
same value can be supplied by an environment variable or a file.
Implementations
Sourceimpl ArgumentError
impl ArgumentError